@@ -1,10 +1,17 @@
 from .core import Problem, Objective, Constraint, Memory
-from .problems import SimpleProblem
-from .wrappers import ProblemWrapper, DiscretizeRegGrid
+from .wrappers import (
+    ProblemWrapper,
+    DiscretizeRegGrid,
+    LocalFD,
+    SimpleProblem,
+    SimpleObjective,
+    SimpleConstraint,
+)
 
 from . import utils
 from . import interfaces
 from . import benchmarks
+from . import optimizers
 
 from importlib.resources import read_text
 
